# frozen_string_literal: true

require 'puppet/provider'

# clase AdvancedSecurityPolicy
class AdvancedSecurityPolicy
  # returns the key and hash value given the policy name
  def self.find_mapping_from_policy_name(name)
    key, value = asp_mapping.find do |_key, hash|
      hash[:name].casecmp(name).zero?
    end
    [key, value]
  end

  # returns the key and hash value given the policy desc
  def self.find_mapping_from_policy_desc(desc)
    name = desc.downcase
    _key, value = asp_mapping.find do |key, _hash|
      key.downcase == name
    end
    unless value
      raise KeyError, "#{desc} is not a valid policy"
    end

    value
  end

  def self.asp_mapping
    @asp_mapping ||= {
      # Computer
      'Prevent enabling lock screen camera' => {
        name: 'Software\Policies\Microsoft\Windows\Personalization\NoLockScreenCamera',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Personalization',
        value_name: 'NoLockScreenCamera',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Prevent enabling lock screen slide show' => {
        name: 'Software\Policies\Microsoft\Windows\Personalization\NoLockScreenSlideshow',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Personalization',
        value_name: 'NoLockScreenSlideshow',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow Input Personalization' => {
        name: 'Software\Policies\Microsoft\InputPersonalization\AllowInputPersonalization',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\InputPersonalization',
        value_name: 'AllowInputPersonalization',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'MSS: (AutoAdminLogon) Enable Automatic Logon (not recommended)' => {
        name: 'Software\Microsoft\Windows NT\CurrentVersion\Winlogon\AutoAdminLogon',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows NT\CurrentVersion\Winlogon',
        value_name: 'AutoAdminLogon',
        reg_type: 'SZ',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'MSS: (DisableIPSourceRouting IPv6) IP source routing protection level (protects against packet spoofing)' => {
        name: 'System\CurrentControlSet\Services\Tcpip6\Parameters\DisableIPSourceRouting',
        configuration: 'Computer',
        registry_key: 'System\CurrentControlSet\Services\Tcpip6\Parameters',
        value_name: 'DisableIPSourceRouting',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'MSS: (DisableIPSourceRouting) IP source routing protection level (protects against packet spoofing)' => {
        name: 'System\CurrentControlSet\Services\Tcpip\Parameters\DisableIPSourceRouting',
        configuration: 'Computer',
        registry_key: 'System\CurrentControlSet\Services\Tcpip\Parameters',
        value_name: 'DisableIPSourceRouting',
        reg_type: 'DWORD',
        data_type: 'string',
        disabled_value: '0',
      },
      'MSS: (EnableICMPRedirect) Allow ICMP redirects to override OSPF generated routes' => {
        name: 'System\CurrentControlSet\Services\Tcpip\Parameters\EnableICMPRedirect',
        configuration: 'Computer',
        registry_key: 'System\CurrentControlSet\Services\Tcpip\Parameters',
        value_name: 'EnableICMPRedirect',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'MSS: (KeepAliveTime) How often keep-alive packets are sent in milliseconds' => {
        name: 'System\CurrentControlSet\Services\Tcpip\Parameters\KeepAliveTime',
        configuration: 'Computer',
        registry_key: 'System\CurrentControlSet\Services\Tcpip\Parameters',
        value_name: 'KeepAliveTime',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'MSS: (NoNameReleaseOnDemand) Allow the computer to ignore NetBIOS name release requests except from WINS servers' => {
        name: 'System\CurrentControlSet\Services\Netbt\Parameters\NoNameReleaseOnDemand',
        configuration: 'Computer',
        registry_key: 'System\CurrentControlSet\Services\Netbt\Parameters',
        value_name: 'NoNameReleaseOnDemand',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'MSS: (PerformRouterDiscovery) Allow IRDP to detect and configure Default Gateway addresses (could lead to DoS)' => {
        name: 'System\CurrentControlSet\Services\Tcpip\Parameters\PerformRouterDiscovery',
        configuration: 'Computer',
        registry_key: 'System\CurrentControlSet\Services\Tcpip\Parameters',
        value_name: 'PerformRouterDiscovery',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'MSS: (SafeDllSearchMode) Enable Safe DLL search mode (recommended)' => {
        name: 'System\CurrentControlSet\Control\Session Manager\SafeDllSearchMode',
        configuration: 'Computer',
        registry_key: 'System\CurrentControlSet\Control\Session Manager',
        value_name: 'SafeDllSearchMode',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'MSS: (ScreenSaverGracePeriod) The time in seconds before the screen saver grace period expires (0 recommended)' => {
        name: 'Software\Microsoft\Windows NT\CurrentVersion\Winlogon\ScreenSaverGracePeriod',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows NT\CurrentVersion\Winlogon',
        value_name: 'ScreenSaverGracePeriod',
        reg_type: 'SZ',
        data_type: 'string',
      },
      'MSS: (TcpMaxDataRetransmissions IPv6) How many times unacknowledged data is retransmitted' => {
        name: 'System\CurrentControlSet\Services\Tcpip6\Parameters\TcpMaxDataRetransmissions',
        configuration: 'Computer',
        registry_key: 'System\CurrentControlSet\Services\Tcpip6\Parameters',
        value_name: 'TcpMaxDataRetransmissions',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'MSS: (TcpMaxDataRetransmissions) How many times unacknowledged data is retransmitted' => {
        name: 'System\CurrentControlSet\Services\Tcpip\Parameters\TcpMaxDataRetransmissions',
        configuration: 'Computer',
        registry_key: 'System\CurrentControlSet\Services\Tcpip\Parameters',
        value_name: 'TcpMaxDataRetransmissions',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'MSS: (WarningLevel) Percentage threshold for the security event log at which the system will generate a warning' => {
        name: 'System\CurrentControlSet\Services\Eventlog\Security\WarningLevel',
        configuration: 'Computer',
        registry_key: 'System\CurrentControlSet\Services\Eventlog\Security',
        value_name: 'WarningLevel',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'NetBIOS node type' => {
        name: 'System\CurrentControlSet\Services\Netbt\Parameters\NodeType',
        configuration: 'Computer',
        registry_key: 'System\CurrentControlSet\Services\Netbt\Parameters',
        value_name: 'NodeType',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Turn off multicast name resolution' => {
        name: 'Software\Policies\Microsoft\Windows NT\DNSClient\EnableMulticast',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\DNSClient',
        value_name: 'EnableMulticast',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Enable Font Providers' => {
        name: 'Software\Policies\Microsoft\Windows\System\EnableFontProviders',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\System',
        value_name: 'EnableFontProviders',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Enable insecure guest logons' => {
        name: 'Software\Policies\Microsoft\Windows\LanmanWorkstation\AllowInsecureGuestAuth',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\LanmanWorkstation',
        value_name: 'AllowInsecureGuestAuth',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn on Mapper I/O (LLTDIO) driver (EnableLLTDIO)' => {
        name: 'Software\Policies\Microsoft\Windows\LLTD\EnableLLTDIO',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\LLTD',
        value_name: 'EnableLLTDIO',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn on Mapper I/O (LLTDIO) driver (AllowLLTDIOOndomain)' => {
        name: 'Software\Policies\Microsoft\Windows\LLTD\AllowLLTDIOOndomain',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\LLTD',
        value_name: 'AllowLLTDIOOndomain',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn on Mapper I/O (LLTDIO) driver (AllowLLTDIOOnPublicNet)' => {
        name: 'Software\Policies\Microsoft\Windows\LLTD\AllowLLTDIOOnPublicNet',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\LLTD',
        value_name: 'AllowLLTDIOOnPublicNet',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn on Mapper I/O (LLTDIO) driver (ProhibitLLTDIOOnPrivateNet)' => {
        name: 'Software\Policies\Microsoft\Windows\LLTD\ProhibitLLTDIOOnPrivateNet',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\LLTD',
        value_name: 'ProhibitLLTDIOOnPrivateNet',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn on Responder (RSPNDR) driver (EnableRspndr)' => {
        name: 'Software\Policies\Microsoft\Windows\LLTD\EnableRspndr',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\LLTD',
        value_name: 'EnableRspndr',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn on Responder (RSPNDR) driver (AllowRspndrOndomain)' => {
        name: 'Software\Policies\Microsoft\Windows\LLTD\AllowRspndrOndomain',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\LLTD',
        value_name: 'AllowRspndrOndomain',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn on Responder (RSPNDR) driver (AllowRspndrOnPublicNet)' => {
        name: 'Software\Policies\Microsoft\Windows\LLTD\AllowRspndrOnPublicNet',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\LLTD',
        value_name: 'AllowRspndrOnPublicNet',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn on Responder (RSPNDR) driver (ProhibitRspndrOnPrivateNet)' => {
        name: 'Software\Policies\Microsoft\Windows\LLTD\ProhibitRspndrOnPrivateNet',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\LLTD',
        value_name: 'ProhibitRspndrOnPrivateNet',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off Microsoft Peer-to-Peer Networking Services' => {
        name: 'Software\Policies\Microsoft\Peernet\Disabled',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Peernet',
        value_name: 'Disabled',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Prohibit installation and configuration of Network Bridge on your DNS domain network' => {
        name: 'Software\Policies\Microsoft\Windows\Network Connections\NC_AllowNetBridge_NLA',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Network Connections',
        value_name: 'NC_AllowNetBridge_NLA',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Require domain users to elevate when setting a network`s location' => {
        name: 'Software\Policies\Microsoft\Windows\Network Connections\NC_StdDomainUserSetLocation',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Network Connections',
        value_name: 'NC_StdDomainUserSetLocation',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Prohibit use of Internet Connection Sharing on your DNS domain network' => {
        name: 'Software\Policies\Microsoft\Windows\Network Connections\NC_ShowSharedAccessUI',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Network Connections',
        value_name: 'NC_ShowSharedAccessUI',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Configuration of wireless settings using Windows Connect Now (EnableRegistrars)' => {
        name: 'Software\Policies\Microsoft\Windows\WCN\Registrars\EnableRegistrars',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\WCN\Registrars',
        value_name: 'EnableRegistrars',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Configuration of wireless settings using Windows Connect Now (DisableUPnPRegistrar)' => {
        name: 'Software\Policies\Microsoft\Windows\WCN\Registrars\DisableUPnPRegistrar',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\WCN\Registrars',
        value_name: 'DisableUPnPRegistrar',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Configuration of wireless settings using Windows Connect Now (DisableInBand802DOT11Registrar)' => {
        name: 'Software\Policies\Microsoft\Windows\WCN\Registrars\DisableInBand802DOT11Registrar',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\WCN\Registrars',
        value_name: 'DisableInBand802DOT11Registrar',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Configuration of wireless settings using Windows Connect Now (DisableFlashConfigRegistrar)' => {
        name: 'Software\Policies\Microsoft\Windows\WCN\Registrars\DisableFlashConfigRegistrar',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\WCN\Registrars',
        value_name: 'DisableFlashConfigRegistrar',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Configuration of wireless settings using Windows Connect Now (DisableWPDRegistrar)' => {
        name: 'Software\Policies\Microsoft\Windows\WCN\Registrars\DisableWPDRegistrar',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\WCN\Registrars',
        value_name: 'DisableWPDRegistrar',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Prohibit access of the Windows Connect Now wizards' => {
        name: 'Software\Policies\Microsoft\Windows\WCN\UI\DisableWcnUi',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\WCN\UI',
        value_name: 'DisableWcnUi',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Minimize the number of simultaneous connections to the Internet or a Windows Domain' => {
        name: 'Software\Policies\Microsoft\Windows\WcmSvc\GroupPolicy\fMinimizeConnections',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\WcmSvc\GroupPolicy',
        value_name: 'fMinimizeConnections',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Prohibit connection to non-domain networks when connected to domain authenticated network' => {
        name: 'Software\Policies\Microsoft\Windows\WcmSvc\GroupPolicy\fBlockNonDomain',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\WcmSvc\GroupPolicy',
        value_name: 'fBlockNonDomain',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off notifications network usage' => {
        name: 'Software\Policies\Microsoft\Windows\CurrentVersion\PushNotifications\NoCloudApplicationNotification',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\CurrentVersion\PushNotifications',
        value_name: 'NoCloudApplicationNotification',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Apply UAC restrictions to local accounts on network logons' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\System\LocalAccountTokenFilterPolicy',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\System',
        value_name: 'LocalAccountTokenFilterPolicy',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'WDigest Authentication' => {
        name: 'System\CurrentControlSet\Control\SecurityProviders\WDigest\UseLogonCredential',
        configuration: 'Computer',
        registry_key: 'System\CurrentControlSet\Control\SecurityProviders\WDigest',
        value_name: 'UseLogonCredential',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Encryption Oracle Remediation' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\System\CredSSP\Parameters\AllowEncryptionOracle',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\System\CredSSP\Parameters',
        value_name: 'AllowEncryptionOracle',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Include command line in process creation events' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\System\Audit\ProcessCreationIncludeCmdLine_Enabled',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\System\Audit',
        value_name: 'ProcessCreationIncludeCmdLine_Enabled',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow remote access to the Plug and Play interface' => {
        name: 'Software\Policies\Microsoft\Windows\DeviceInstall\Settings\AllowRemoteRPC',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\DeviceInstall\Settings',
        value_name: 'AllowRemoteRPC',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Boot-Start Driver Initialization Policy' => {
        name: 'System\CurrentControlSet\Policies\EarlyLaunch\DriverLoadPolicy',
        configuration: 'Computer',
        registry_key: 'System\CurrentControlSet\Policies\EarlyLaunch',
        value_name: 'DriverLoadPolicy',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Configure registry policy processing: Do not apply during periodic background processing' => {
        name: 'Software\Policies\Microsoft\Windows\Group Policy\{35378EAC-683F-11D2-A89A-00C04FBBCFA2}\NoBackgroundPolicy',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Group Policy\{35378EAC-683F-11D2-A89A-00C04FBBCFA2}',
        value_name: 'NoBackgroundPolicy',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Configure registry policy processing: Process even if the Group Policy objects have not changed' => {
        name: 'Software\Policies\Microsoft\Windows\Group Policy\{35378EAC-683F-11D2-A89A-00C04FBBCFA2}\NoGPOListChanges',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Group Policy\{35378EAC-683F-11D2-A89A-00C04FBBCFA2}',
        value_name: 'NoGPOListChanges',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Configure security policy processing: Do not apply during periodic background processing' => {
        name: 'Software\Policies\Microsoft\Windows\Group Policy\{827D319E-6EAC-11D2-A4EA-00C04F79F83A}\NoBackgroundPolicy',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Group Policy\{827D319E-6EAC-11D2-A4EA-00C04F79F83A}',
        value_name: 'NoBackgroundPolicy',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Configure security policy processing: Process even if the Group Policy objects have not changed' => {
        name: 'Software\Policies\Microsoft\Windows\Group Policy\{827D319E-6EAC-11D2-A4EA-00C04F79F83A}\NoGPOListChanges',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Group Policy\{827D319E-6EAC-11D2-A4EA-00C04F79F83A}',
        value_name: 'NoGPOListChanges',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Turn off background refresh of Group Policy' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\System\DisableBkGndGroupPolicy',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\System',
        value_name: 'DisableBkGndGroupPolicy',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Continue experiences on this device' => {
        name: 'Software\Policies\Microsoft\Windows\System\EnableCdp',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\System',
        value_name: 'EnableCdp',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off access to the Store' => {
        name: 'Software\Policies\Microsoft\Windows\Explorer\NoUseStoreOpenWith',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Explorer',
        value_name: 'NoUseStoreOpenWith',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off downloading of print drivers over HTTP' => {
        name: 'Software\Policies\Microsoft\Windows NT\Printers\DisableWebPnPDownload',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Printers',
        value_name: 'DisableWebPnPDownload',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off handwriting personalization data sharing' => {
        name: 'Software\Policies\Microsoft\Windows\TabletPC\PreventHandwritingDataSharing',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\TabletPC',
        value_name: 'PreventHandwritingDataSharing',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off handwriting recognition error reporting' => {
        name: 'Software\Policies\Microsoft\Windows\HandwritingErrorReports\PreventHandwritingErrorReports',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\HandwritingErrorReports',
        value_name: 'PreventHandwritingErrorReports',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off Internet Connection Wizard if URL connection is referring to Microsoft.com' => {
        name: 'Software\Policies\Microsoft\Windows\Internet Connection Wizard\ExitOnMSICW',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Internet Connection Wizard',
        value_name: 'ExitOnMSICW',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off Internet download for Web publishing and online ordering wizards' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\Explorer\NoWebServices',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\Explorer',
        value_name: 'NoWebServices',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off Internet File Association service' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\Explorer\NoInternetOpenWith',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\Explorer',
        value_name: 'NoInternetOpenWith',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off printing over HTTP' => {
        name: 'Software\Policies\Microsoft\Windows NT\Printers\DisableHTTPPrinting',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Printers',
        value_name: 'DisableHTTPPrinting',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off Registration if URL connection is referring to Microsoft.com' => {
        name: 'Software\Policies\Microsoft\Windows\Registration Wizard Control\NoRegistration',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Registration Wizard Control',
        value_name: 'NoRegistration',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off Search Companion content file updates' => {
        name: 'Software\Policies\Microsoft\SearchCompanion\DisableContentFileUpdates',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\SearchCompanion',
        value_name: 'DisableContentFileUpdates',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off the "Order Prints" picture task' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\Explorer\NoOnlinePrintsWizard',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\Explorer',
        value_name: 'NoOnlinePrintsWizard',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off the "Publish to Web" task for files and folders' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\Explorer\NoPublishingWizard',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\Explorer',
        value_name: 'NoPublishingWizard',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off the Windows Messenger Customer Experience Improvement Program' => {
        name: 'Software\Policies\Microsoft\Messenger\Client\CEIP',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Messenger\Client',
        value_name: 'CEIP',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '2',
        disabled_value: '1',
      },
      'Turn off Windows Customer Experience Improvement Program' => {
        name: 'Software\Policies\Microsoft\SQMClient\Windows\CEIPEnable',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\SQMClient\Windows',
        value_name: 'CEIPEnable',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Turn off Windows Error Reporting' => {
        name: 'Software\Policies\Microsoft\Windows\Windows Error Reporting\Disabled',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Windows Error Reporting',
        value_name: 'Disabled',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Support device authentication using certificate (DevicePKInitEnabled)' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\System\kerberos\parameters\DevicePKInitEnabled',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\System\kerberos\parameters',
        value_name: 'DevicePKInitEnabled',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Support device authentication using certificate (DevicePKInitBehavior)' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\System\kerberos\parameters\DevicePKInitBehavior',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\System\kerberos\parameters',
        value_name: 'DevicePKInitBehavior',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Enumeration policy for external devices incompatible with Kernel DMA Protection' => {
        name: 'Software\Policies\Microsoft\Windows\Kernel DMA Protection\DeviceEnumerationPolicy',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Kernel DMA Protection',
        value_name: 'DeviceEnumerationPolicy',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Disallow copying of user input methods to the system account for sign-in' => {
        name: 'Software\Policies\Microsoft\Control Panel\International\BlockUserInputMethodsForSignIn',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Control Panel\International',
        value_name: 'BlockUserInputMethodsForSignIn',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Always use classic logon' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\System\LogonType',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\System',
        value_name: 'LogonType',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Do not display network selection UI' => {
        name: 'Software\Policies\Microsoft\Windows\System\DontDisplayNetworkSelectionUI',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\System',
        value_name: 'DontDisplayNetworkSelectionUI',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Do not enumerate connected users on domain-joined computers' => {
        name: 'Software\Policies\Microsoft\Windows\System\DontEnumerateConnectedUsers',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\System',
        value_name: 'DontEnumerateConnectedUsers',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Enumerate local users on domain-joined computers' => {
        name: 'Software\Policies\Microsoft\Windows\System\EnumerateLocalUsers',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\System',
        value_name: 'EnumerateLocalUsers',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off app notifications on the lock screen' => {
        name: 'Software\Policies\Microsoft\Windows\System\DisableLockScreenAppNotifications',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\System',
        value_name: 'DisableLockScreenAppNotifications',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn on convenience PIN sign-in' => {
        name: 'Software\Policies\Microsoft\Windows\System\AllowDomainPINLogon',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\System',
        value_name: 'AllowDomainPINLogon',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow Clipboard synchronization across devices' => {
        name: 'Software\Policies\Microsoft\Windows\System\AllowCrossDeviceClipboard',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\System',
        value_name: 'AllowCrossDeviceClipboard',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow upload of User Activities' => {
        name: 'Software\Policies\Microsoft\Windows\System\UploadUserActivities',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\System',
        value_name: 'UploadUserActivities',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Block user from showing account details on sign-in' => {
        name: 'Software\Policies\Microsoft\Windows\System\BlockUserFromShowingAccountDetailsOnSignin',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\System',
        value_name: 'BlockUserFromShowingAccountDetailsOnSignin',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Untrusted Font Blocking' => {
        name: 'Software\Policies\Microsoft\Windows NT\MitigationOptions\MitigationOptions_FontBocking',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\MitigationOptions',
        value_name: 'MitigationOptions_FontBocking',
        reg_type: 'SZ',
        data_type: 'string',
      },
      'Allow network connectivity during connected-standby (on battery)' => {
        name: 'Software\Policies\Microsoft\Power\PowerSettings\f15576e8-98b7-4186-b944-eafa664402d9\DCSettingIndex',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Power\PowerSettings\f15576e8-98b7-4186-b944-eafa664402d9',
        value_name: 'DCSettingIndex',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow network connectivity during connected-standby (plugged in)' => {
        name: 'Software\Policies\Microsoft\Power\PowerSettings\f15576e8-98b7-4186-b944-eafa664402d9\ACSettingIndex',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Power\PowerSettings\f15576e8-98b7-4186-b944-eafa664402d9',
        value_name: 'ACSettingIndex',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Require a password when a computer wakes (on battery)' => {
        name: 'Software\Policies\Microsoft\Power\PowerSettings\0e796bdb-100d-47d6-a2d5-f7d2daa51f51\DCSettingIndex',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Power\PowerSettings\0e796bdb-100d-47d6-a2d5-f7d2daa51f51',
        value_name: 'DCSettingIndex',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Require a password when a computer wakes (plugged in)' => {
        name: 'Software\Policies\Microsoft\Power\PowerSettings\0e796bdb-100d-47d6-a2d5-f7d2daa51f51\ACSettingIndex',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Power\PowerSettings\0e796bdb-100d-47d6-a2d5-f7d2daa51f51',
        value_name: 'ACSettingIndex',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Configure Offer Remote Assistance' => {
        name: 'Software\Policies\Microsoft\Windows NT\Terminal Services\fAllowUnsolicited',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Terminal Services',
        value_name: 'fAllowUnsolicited',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Configure Solicited Remote Assistance' => {
        name: 'Software\Policies\Microsoft\Windows NT\Terminal Services\fAllowToGetHelp',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Terminal Services',
        value_name: 'fAllowToGetHelp',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Enable RPC Endpoint Mapper Client Authentication' => {
        name: 'Software\Policies\Microsoft\Windows NT\Rpc\EnableAuthEpResolution',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Rpc',
        value_name: 'EnableAuthEpResolution',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Restrict Unauthenticated RPC clients' => {
        name: 'Software\Policies\Microsoft\Windows NT\Rpc\RestrictRemoteClients',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Rpc',
        value_name: 'RestrictRemoteClients',
        reg_type: 'DWORD',
        data_type: 'string',
        disabled_value: '0',
      },
      'Microsoft Support Diagnostic Tool: Turn on MSDT interactive communication with support provider' => {
        name: 'Software\Policies\Microsoft\Windows\ScriptedDiagnosticsProvider\Policy\DisableQueryRemoteServer',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\ScriptedDiagnosticsProvider\Policy',
        value_name: 'DisableQueryRemoteServer',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Enable/Disable PerfTrack' => {
        name: 'Software\Policies\Microsoft\Windows\WDI\{9c5a40da-b965-4fc3-8781-88dd50a6299d}\ScenarioExecutionEnabled',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\WDI\{9c5a40da-b965-4fc3-8781-88dd50a6299d}',
        value_name: 'ScenarioExecutionEnabled',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off the advertising ID' => {
        name: 'Software\Policies\Microsoft\Windows\AdvertisingInfo\DisabledByGroupPolicy',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\AdvertisingInfo',
        value_name: 'DisabledByGroupPolicy',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Enable Windows NTP Client' => {
        name: 'Software\Policies\Microsoft\W32time\TimeProviders\NtpClient\Enabled',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\W32time\TimeProviders\NtpClient',
        value_name: 'Enabled',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Enable Windows NTP Server' => {
        name: 'Software\Policies\Microsoft\W32time\TimeProviders\NtpServer\Enabled',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\W32time\TimeProviders\NtpServer',
        value_name: 'Enabled',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow a Windows app to share application data between users' => {
        name: 'Software\Policies\Microsoft\Windows\CurrentVersion\AppModel\StateManager\AllowSharedLocalAppData',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\CurrentVersion\AppModel\StateManager',
        value_name: 'AllowSharedLocalAppData',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Let Windows apps *' => {
        name: 'Software\Policies\Microsoft\Windows\AppPrivacy\LetAppsAccessAccountInfo',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\AppPrivacy',
        value_name: 'LetAppsAccessAccountInfo',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Allow Microsoft accounts to be optional' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\System\MSAOptional',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\System',
        value_name: 'MSAOptional',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Block launching Windows Store apps with Windows Runtime API access from hosted content.' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\System\BlockHostedAppAccessWinRT',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\System',
        value_name: 'BlockHostedAppAccessWinRT',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Disallow Autoplay for non-volume devices' => {
        name: 'Software\Policies\Microsoft\Windows\Explorer\NoAutoplayfornonVolume',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Explorer',
        value_name: 'NoAutoplayfornonVolume',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Set the default behavior for AutoRun' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\Explorer\NoAutorun',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\Explorer',
        value_name: 'NoAutorun',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Turn off Autoplay' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\Explorer\NoDriveTypeAutoRun',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\Explorer',
        value_name: 'NoDriveTypeAutoRun',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Use enhanced anti-spoofing when available' => {
        name: 'Software\Policies\Microsoft\Biometrics\FacialFeatures\EnhancedAntiSpoofing',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Biometrics\FacialFeatures',
        value_name: 'EnhancedAntiSpoofing',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow Use of Camera' => {
        name: 'Software\Policies\Microsoft\Camera\AllowCamera',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Camera',
        value_name: 'AllowCamera',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off Microsoft consumer experiences' => {
        name: 'Software\Policies\Microsoft\Windows\CloudContent\DisableWindowsConsumerFeatures',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\CloudContent',
        value_name: 'DisableWindowsConsumerFeatures',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Require pin for pairing' => {
        name: 'Software\Policies\Microsoft\Windows\Connect\RequirePinForPairing',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Connect',
        value_name: 'RequirePinForPairing',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Do not display the password reveal button' => {
        name: 'Software\Policies\Microsoft\Windows\CredUI\DisablePasswordReveal',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\CredUI',
        value_name: 'DisablePasswordReveal',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Enumerate administrator accounts on elevation' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\CredUI\EnumerateAdministrators',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\CredUI',
        value_name: 'EnumerateAdministrators',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow Telemetry' => {
        name: 'Software\Policies\Microsoft\Windows\DataCollection\AllowTelemetry',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\DataCollection',
        value_name: 'AllowTelemetry',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Disable pre-release features or settings' => {
        name: 'Software\Policies\Microsoft\Windows\PreviewBuilds\EnableConfigFlighting',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\PreviewBuilds',
        value_name: 'EnableConfigFlighting',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Do not show feedback notifications' => {
        name: 'Software\Policies\Microsoft\Windows\DataCollection\DoNotShowFeedbackNotifications',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\DataCollection',
        value_name: 'DoNotShowFeedbackNotifications',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Toggle user control over Insider builds' => {
        name: 'Software\Policies\Microsoft\Windows\PreviewBuilds\AllowBuildPreview',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\PreviewBuilds',
        value_name: 'AllowBuildPreview',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off desktop gadgets' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\Windows\Sidebar\TurnOffSidebar',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\Windows\Sidebar',
        value_name: 'TurnOffSidebar',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn Off user-installed desktop gadgets' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\Windows\Sidebar\TurnOffUserInstalledGadgets',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\Windows\Sidebar',
        value_name: 'TurnOffUserInstalledGadgets',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Application: Control Event Log behavior when the log file reaches its maximum size' => {
        name: 'Software\Policies\Microsoft\Windows\EventLog\Application\Retention',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\EventLog\Application',
        value_name: 'Retention',
        reg_type: 'SZ',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Application: Specify the maximum log file size (KB)' => {
        name: 'Software\Policies\Microsoft\Windows\EventLog\Application\MaxSize',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\EventLog\Application',
        value_name: 'MaxSize',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Security: Control Event Log behavior when the log file reaches its maximum size' => {
        name: 'Software\Policies\Microsoft\Windows\EventLog\Security\Retention',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\EventLog\Security',
        value_name: 'Retention',
        reg_type: 'SZ',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Security: Specify the maximum log file size (KB)' => {
        name: 'Software\Policies\Microsoft\Windows\EventLog\Security\MaxSize',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\EventLog\Security',
        value_name: 'MaxSize',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Setup: Control Event Log behavior when the log file reaches its maximum size' => {
        name: 'Software\Policies\Microsoft\Windows\EventLog\Setup\Retention',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\EventLog\Setup',
        value_name: 'Retention',
        reg_type: 'SZ',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Setup: Specify the maximum log file size (KB)' => {
        name: 'Software\Policies\Microsoft\Windows\EventLog\Setup\MaxSize',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\EventLog\Setup',
        value_name: 'MaxSize',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'System: Control Event Log behavior when the log file reaches its maximum size' => {
        name: 'Software\Policies\Microsoft\Windows\EventLog\System\Retention',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\EventLog\System',
        value_name: 'Retention',
        reg_type: 'SZ',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'System: Specify the maximum log file size (KB)' => {
        name: 'Software\Policies\Microsoft\Windows\EventLog\System\MaxSize',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\EventLog\System',
        value_name: 'MaxSize',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Configure Windows SmartScreen' => {
        name: 'Software\Policies\Microsoft\Windows\System\EnableSmartScreen',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\System',
        value_name: 'EnableSmartScreen',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Configure Windows SmartScreen (Level)' => {
        name: 'Software\Policies\Microsoft\Windows\System\ShellSmartScreenLevel',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\System',
        value_name: 'ShellSmartScreenLevel',
        reg_type: 'SZ',
        data_type: 'string',
      },
      'Turn off Data Execution Prevention for Explorer' => {
        name: 'Software\Policies\Microsoft\Windows\Explorer\NoDataExecutionPrevention',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Explorer',
        value_name: 'NoDataExecutionPrevention',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Do not apply the Mark of the Web tag to files copied from insecure sources' => {
        name: 'Software\Policies\Microsoft\Windows\Explorer\DisableMotWOnInsecurePathCopy',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Explorer',
        value_name: 'DisableMotWOnInsecurePathCopy',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off heap termination on corruption' => {
        name: 'Software\Policies\Microsoft\Windows\Explorer\NoHeapTerminationOnCorruption',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Explorer',
        value_name: 'NoHeapTerminationOnCorruption',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off shell protocol protected mode' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\Explorer\PreXPSP2ShellProtocolBehavior',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\Explorer',
        value_name: 'PreXPSP2ShellProtocolBehavior',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off location' => {
        name: 'Software\Policies\Microsoft\Windows\LocationAndSensors\DisableLocation',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\LocationAndSensors',
        value_name: 'DisableLocation',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow Extensions' => {
        name: 'Software\Policies\Microsoft\MicrosoftEdge\Extensions\ExtensionsEnabled',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\MicrosoftEdge\Extensions',
        value_name: 'ExtensionsEnabled',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow InPrivate Browsing' => {
        name: 'Software\Policies\Microsoft\MicrosoftEdge\Main\AllowInPrivate',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\MicrosoftEdge\Main',
        value_name: 'AllowInPrivate',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Configure cookies' => {
        name: 'Software\Policies\Microsoft\MicrosoftEdge\Main\Cookies',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\MicrosoftEdge\Main',
        value_name: 'Cookies',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Configure Pop-up Blocker' => {
        name: 'Software\Policies\Microsoft\MicrosoftEdge\Main\AllowPopups',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\MicrosoftEdge\Main',
        value_name: 'AllowPopups',
        reg_type: 'SZ',
        data_type: 'string',
      },
      'Configure search suggestions in Address bar' => {
        name: 'Software\Policies\Microsoft\MicrosoftEdge\SearchScopes\ShowSearchSuggestionsGlobal',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\MicrosoftEdge\SearchScopes',
        value_name: 'ShowSearchSuggestionsGlobal',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Configure Password Manager' => {
        name: 'Software\Policies\Microsoft\MicrosoftEdge\Main\FormSuggest Passwords',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\MicrosoftEdge\Main',
        value_name: 'FormSuggest Passwords',
        reg_type: 'SZ',
        data_type: 'string',
      },
      'Configure SmartScreen Filter' => {
        name: 'Software\Policies\Microsoft\MicrosoftEdge\PhishingFilter\EnabledV9',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\MicrosoftEdge\PhishingFilter',
        value_name: 'EnabledV9',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Prevent access to the about: flags page in Microsoft Edge' => {
        name: 'Software\Policies\Microsoft\MicrosoftEdge\Main\PreventAccessToAboutFlagsInMicrosoftEdge',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\MicrosoftEdge\Main',
        value_name: 'PreventAccessToAboutFlagsInMicrosoftEdge',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Prevent bypassing SmartScreen prompts for files' => {
        name: 'Software\Policies\Microsoft\MicrosoftEdge\PhishingFilter\PreventOverrideAppRepUnknown',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\MicrosoftEdge\PhishingFilter',
        value_name: 'PreventOverrideAppRepUnknown',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Prevent bypassing SmartScreen prompts for sites' => {
        name: 'Software\Policies\Microsoft\MicrosoftEdge\PhishingFilter\PreventOverride',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\MicrosoftEdge\PhishingFilter',
        value_name: 'PreventOverride',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Prevent using Localhost IP address for WebRTC' => {
        name: 'Software\Policies\Microsoft\MicrosoftEdge\Main\HideLocalHostIP',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\MicrosoftEdge\Main',
        value_name: 'HideLocalHostIP',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Prevent the usage of OneDrive for file storage (DisableFileSync)' => {
        name: 'Software\Policies\Microsoft\Windows\Skydrive\DisableFileSync',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Skydrive',
        value_name: 'DisableFileSync',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Prevent the usage of OneDrive for file storage (DisableFileSyncNGSC)' => {
        name: 'Software\Policies\Microsoft\Windows\OneDrive\DisableFileSyncNGSC',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\OneDrive',
        value_name: 'DisableFileSyncNGSC',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Do not allow passwords to be saved' => {
        name: 'Software\Policies\Microsoft\Windows NT\Terminal Services\DisablePasswordSaving',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Terminal Services',
        value_name: 'DisablePasswordSaving',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Do not allow client printer redirection' => {
        name: 'Software\Policies\Microsoft\Windows NT\Terminal Services\fDisableCpm',
        configuration: 'Computer',
        registry_key: 'SOFTWARE\Policies\Microsoft\Windows NT\Terminal Services',
        value_name: 'fDisableCpm',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Restrict Remote Desktop Services users to a single Remote Desktop Services session' => {
        name: 'Software\Policies\Microsoft\Windows NT\Terminal Services\fSingleSessionPerUser',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Terminal Services',
        value_name: 'fSingleSessionPerUser',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Do not allow COM port redirection' => {
        name: 'Software\Policies\Microsoft\Windows NT\Terminal Services\fDisableCcm',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Terminal Services',
        value_name: 'fDisableCcm',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Do not allow LPT port redirection' => {
        name: 'Software\Policies\Microsoft\Windows NT\Terminal Services\fDisableLPT',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Terminal Services',
        value_name: 'fDisableLPT',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Do not allow supported Plug and Play device redirection' => {
        name: 'Software\Policies\Microsoft\Windows NT\Terminal Services\fDisablePNPRedir',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Terminal Services',
        value_name: 'fDisablePNPRedir',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Always prompt for password upon connection' => {
        name: 'Software\Policies\Microsoft\Windows NT\Terminal Services\fPromptForPassword',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Terminal Services',
        value_name: 'fPromptForPassword',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Require secure RPC communication' => {
        name: 'Software\Policies\Microsoft\Windows NT\Terminal Services\fEncryptRPCTraffic',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Terminal Services',
        value_name: 'fEncryptRPCTraffic',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Require use of specific security layer for remote (RDP) connections' => {
        name: 'Software\Policies\Microsoft\Windows NT\Terminal Services\SecurityLayer',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Terminal Services',
        value_name: 'SecurityLayer',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Require user authentication for remote connections by using Network Level Authentication' => {
        name: 'Software\Policies\Microsoft\Windows NT\Terminal Services\UserAuthentication',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Terminal Services',
        value_name: 'UserAuthentication',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Set client connection encryption level' => {
        name: 'Software\Policies\Microsoft\Windows NT\Terminal Services\MinEncryptionLevel',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Terminal Services',
        value_name: 'MinEncryptionLevel',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Set time limit for active but idle Remote Desktop Services sessions' => {
        name: 'Software\Policies\Microsoft\Windows NT\Terminal Services\MaxIdleTime',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Terminal Services',
        value_name: 'MaxIdleTime',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Set time limit for disconnected sessions' => {
        name: 'Software\Policies\Microsoft\Windows NT\Terminal Services\MaxDisconnectionTime',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Terminal Services',
        value_name: 'MaxDisconnectionTime',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Do not delete temp folders upon exit' => {
        name: 'Software\Policies\Microsoft\Windows NT\Terminal Services\DeleteTempDirsOnExit',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Terminal Services',
        value_name: 'DeleteTempDirsOnExit',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Do not use temporary folders per session' => {
        name: 'Software\Policies\Microsoft\Windows NT\Terminal Services\PerSessionTempDir',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Terminal Services',
        value_name: 'PerSessionTempDir',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Prevent downloading of enclosures' => {
        name: 'Software\Policies\Microsoft\Internet Explorer\Feeds\DisableEnclosureDownload',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Internet Explorer\Feeds',
        value_name: 'DisableEnclosureDownload',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow Cortana' => {
        name: 'Software\Policies\Microsoft\Windows\Windows Search\AllowCortana',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Windows Search',
        value_name: 'AllowCortana',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Set what information is shared in Search' => {
        name: 'Software\Policies\Microsoft\Windows\Windows Search\ConnectedSearchPrivacy',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Windows Search',
        value_name: 'ConnectedSearchPrivacy',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Allow indexing of encrypted files' => {
        name: 'Software\Policies\Microsoft\Windows\Windows Search\AllowIndexingEncryptedStoresOrItems',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Windows Search',
        value_name: 'AllowIndexingEncryptedStoresOrItems',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow search and Cortana to use location' => {
        name: 'Software\Policies\Microsoft\Windows\Windows Search\AllowSearchToUseLocation',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Windows Search',
        value_name: 'AllowSearchToUseLocation',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow Cortana above lock screen' => {
        name: 'Software\Policies\Microsoft\Windows\Windows Search\AllowCortanaAboveLock',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Windows Search',
        value_name: 'AllowCortanaAboveLock',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off KMS Client Online AVS Validation' => {
        name: 'Software\Policies\Microsoft\Windows NT\CurrentVersion\Software Protection Platform\NoGenTicket',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\CurrentVersion\Software Protection Platform',
        value_name: 'NoGenTicket',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Disable all apps from Windows Store' => {
        name: 'Software\Policies\Microsoft\WindowsStore\DisableStoreApps',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\WindowsStore',
        value_name: 'DisableStoreApps',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Turn off Automatic Download and Install of updates' => {
        name: 'Software\Policies\Microsoft\WindowsStore\AutoDownload',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\WindowsStore',
        value_name: 'AutoDownload',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Turn off the offer to update to the latest version of Windows' => {
        name: 'Software\Policies\Microsoft\WindowsStore\DisableOSUpgrade',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\WindowsStore',
        value_name: 'DisableOSUpgrade',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off the Store application' => {
        name: 'Software\Policies\Microsoft\WindowsStore\RemoveWindowsStore',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\WindowsStore',
        value_name: 'RemoveWindowsStore',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Join Microsoft MAPS' => {
        name: 'Software\Policies\Microsoft\Windows Defender\Spynet\SpynetReporting',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows Defender\Spynet',
        value_name: 'SpynetReporting',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Configure Watson events' => {
        name: 'Software\Policies\Microsoft\Windows Defender\Reporting\DisableGenericRePorts',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows Defender\Reporting',
        value_name: 'DisableGenericRePorts',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Configure Default consent' => {
        name: 'Software\Policies\Microsoft\Windows\Windows Error Reporting\Consent\DefaultConsent',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Windows Error Reporting\Consent',
        value_name: 'DefaultConsent',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Automatically send memory dumps for OS-generated error reports' => {
        name: 'Software\Policies\Microsoft\Windows\Windows Error Reporting\AutoApproveOSDumps',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Windows Error Reporting',
        value_name: 'AutoApproveOSDumps',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow suggested apps in Windows Ink Workspace' => {
        name: 'Software\Policies\Microsoft\WindowsInkWorkspace\AllowSuggestedAppsInWindowsInkWorkspace',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\WindowsInkWorkspace',
        value_name: 'AllowSuggestedAppsInWindowsInkWorkspace',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow Windows Ink Workspace' => {
        name: 'Software\Policies\Microsoft\WindowsInkWorkspace\AllowWindowsInkWorkspace',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\WindowsInkWorkspace',
        value_name: 'AllowWindowsInkWorkspace',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Allow user control over installs' => {
        name: 'Software\Policies\Microsoft\Windows\Installer\EnableUserControl',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Installer',
        value_name: 'EnableUserControl',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Always install with elevated privileges' => {
        name: 'Software\Policies\Microsoft\Windows\Installer\AlwaysInstallElevated',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Installer',
        value_name: 'AlwaysInstallElevated',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Prevent Internet Explorer security prompt for Windows Installer scripts' => {
        name: 'Software\Policies\Microsoft\Windows\Installer\SafeForScripting',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Installer',
        value_name: 'SafeForScripting',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn on PowerShell Script Block Logging' => {
        name: 'Software\Policies\Microsoft\Windows\PowerShell\ScriptBlockLogging\EnableScriptBlockLogging',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\PowerShell\ScriptBlockLogging',
        value_name: 'EnableScriptBlockLogging',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn on PowerShell Transcription' => {
        name: 'Software\Policies\Microsoft\Windows\PowerShell\Transcription\EnableTranscripting',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\PowerShell\Transcription',
        value_name: 'EnableTranscripting',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow Basic authentication (Client)' => {
        name: 'Software\Policies\Microsoft\Windows\WinRM\Client\AllowBasic',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\WinRM\Client',
        value_name: 'AllowBasic',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow unencrypted traffic (Client)' => {
        name: 'Software\Policies\Microsoft\Windows\WinRM\Client\AllowUnencryptedTraffic',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\WinRM\Client',
        value_name: 'AllowUnencryptedTraffic',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Disallow Digest authentication' => {
        name: 'Software\Policies\Microsoft\Windows\WinRM\Client\AllowDigest',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\WinRM\Client',
        value_name: 'AllowDigest',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Allow Basic authentication (Service)' => {
        name: 'Software\Policies\Microsoft\Windows\WinRM\Service\AllowBasic',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\WinRM\Service',
        value_name: 'AllowBasic',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow remote server management through WinRM' => {
        name: 'Software\Policies\Microsoft\Windows\WinRM\Service\AllowAutoConfig',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\WinRM\Service',
        value_name: 'AllowAutoConfig',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow unencrypted traffic (Service)' => {
        name: 'Software\Policies\Microsoft\Windows\WinRM\Service\AllowUnencryptedTraffic',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\WinRM\Service',
        value_name: 'AllowUnencryptedTraffic',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Disallow WinRM from storing RunAs credentials' => {
        name: 'Software\Policies\Microsoft\Windows\WinRM\Service\DisableRunAs',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\WinRM\Service',
        value_name: 'DisableRunAs',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow Remote Shell Access' => {
        name: 'Software\Policies\Microsoft\Windows\WinRM\Service\WinRS\AllowRemoteShellAccess',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\WinRM\Service\WinRS',
        value_name: 'AllowRemoteShellAccess',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Prevent users from modifying settings' => {
        name: 'Software\Policies\Microsoft\Windows Defender Security Center\App and Browser protection\DisallowExploitProtectionOverride',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows Defender Security Center\App and Browser protection',
        value_name: 'DisallowExploitProtectionOverride',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Configure SMB v1 client driver' => {
        name: 'System\CurrentControlSet\Services\MrxSmb10\Start',
        configuration: 'Computer',
        registry_key: 'System\CurrentControlSet\Services\MrxSmb10',
        value_name: 'Start',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Configure SMB v1 client' => {
        name: 'HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\LanmanWorkstation\DependOnService',
        configuration: 'Computer',
        registry_key: 'HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\LanmanWorkstation',
        value_name: 'DependOnService',
        reg_type: 'MULTISZ',
        data_type: 'string',
      },
      'Configure SMB v1 server' => {
        name: 'System\CurrentControlSet\Services\LanmanServer\Parameters\SMB1',
        configuration: 'Computer',
        registry_key: 'System\CurrentControlSet\Services\LanmanServer\Parameters',
        value_name: 'SMB1',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Remote host allows delegation of non-exportable credentials' => {
        name: 'Software\Policies\Microsoft\Windows\CredentialsDelegation\AllowProtectedCreds',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\CredentialsDelegation',
        value_name: 'AllowProtectedCreds',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off picture password sign-in' => {
        name: 'Software\Policies\Microsoft\Windows\System\BlockDomainPicturePassword',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\System',
        value_name: 'BlockDomainPicturePassword',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off Windows Location Provider' => {
        name: 'Software\Policies\Microsoft\Windows\LocationAndSensors\DisableWindowsLocationProvider',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\LocationAndSensors',
        value_name: 'DisableWindowsLocationProvider',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Configure local setting override for reporting to Microsoft MAPS' => {
        name: 'Software\Policies\Microsoft\Microsoft Antimalware\SpyNet\LocalSettingOverrideSpyNetReporting',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Microsoft Antimalware\SpyNet',
        value_name: 'LocalSettingOverrideSpyNetReporting',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Require Mutual Authentication (NETLOGON)' => {
        name: 'Software\Policies\Microsoft\Windows\NetworkProvider\HardenedPaths\NETLOGON',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\NetworkProvider\HardenedPaths',
        value_name: '\\\\*\NETLOGON',
        reg_type: 'SZ',
        data_type: 'string',
      },
      'Require Mutual Authentication (SYSVOL)' => {
        name: 'Software\Policies\Microsoft\Windows\NetworkProvider\HardenedPaths\SYSVOL',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\NetworkProvider\HardenedPaths',
        value_name: '\\\\*\SYSVOL',
        reg_type: 'SZ',
        data_type: 'string',
      },
      'Allow Online Tips' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\Explorer\AllowOnlineTips',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\Explorer',
        value_name: 'AllowOnlineTips',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Configure Authenticated Proxy usage for the Connected User Experience and Telemetry service' => {
        name: 'Software\Policies\Microsoft\Windows\DataCollection\DisableEnterpriseAuthProxy',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\DataCollection',
        value_name: 'DisableEnterpriseAuthProxy',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow Message Service Cloud Sync' => {
        name: 'Software\Policies\Microsoft\Windows\Messaging\AllowMessageSync',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Messaging',
        value_name: 'AllowMessageSync',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Block all consumer Microsoft account user authentication' => {
        name: 'Software\Policies\Microsoft\MicrosoftAccount\DisableUserAuth',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\MicrosoftAccount',
        value_name: 'DisableUserAuth',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off Windows Error Reporting (PCHealth)' => {
        name: 'Software\Policies\Microsoft\PCHealth\ErrorReporting\DoReport',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\PCHealth\ErrorReporting',
        value_name: 'DoReport',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Do not allow drive redirection' => {
        name: 'Software\Policies\Microsoft\Windows NT\Terminal Services\fDisableCdm',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Terminal Services',
        value_name: 'fDisableCdm',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn on behavior monitoring' => {
        name: 'Software\Policies\Microsoft\Windows Defender\Real-Time Protection\DisableBehaviorMonitoring',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows Defender\Real-Time Protection',
        value_name: 'DisableBehaviorMonitoring',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Scan removable drives' => {
        name: 'Software\Policies\Microsoft\Windows Defender\Scan\DisableRemovableDriveScanning',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows Defender\Scan',
        value_name: 'DisableRemovableDriveScanning',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Turn on e-mail scanning' => {
        name: 'Software\Policies\Microsoft\Windows Defender\Scan\DisableEmailScanning',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows Defender\Scan',
        value_name: 'DisableEmailScanning',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Configure Attack Surface Reduction rules' => {
        name: 'Software\Policies\Microsoft\Windows Defender\Windows Defender Exploit Guard\ASR\ExploitGuard_ASR_Rules',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows Defender\Windows Defender Exploit Guard\ASR',
        value_name: 'ExploitGuard_ASR_Rules',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Prevent users and apps from accessing dangerous websites' => {
        name: 'Software\Policies\Microsoft\Windows Defender\Windows Defender Exploit Guard\Network Protection\EnableNetworkProtection',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows Defender\Windows Defender Exploit Guard\Network Protection',
        value_name: 'EnableNetworkProtection',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Configure detection for potentially unwanted applications' => {
        name: 'Software\Policies\Microsoft\Windows Defender\PUAProtection',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows Defender',
        value_name: 'PUAProtection',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Limits print driver installation to Administrators' => {
        name: 'Software\Policies\Microsoft\Windows NT\Printers\PointAndPrint\RestrictDriverInstallationToAdministrators',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Printers\PointAndPrint',
        value_name: 'RestrictDriverInstallationToAdministrators',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Configure DNS over HTTPS (DoH) name resolution' => {
        name: 'Software\Policies\Microsoft\Windows NT\DNSClient\DoHPolicy',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\DNSClient',
        value_name: 'DoHPolicy',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Allow Print Spooler to accept client connections' => {
        name: 'Software\Policies\Microsoft\Windows NT\Printers\RegisterSpoolerRemoteRpcEndPoint',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Printers',
        value_name: 'RegisterSpoolerRemoteRpcEndPoint',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '2',
      },
      'Point and Print Restrictions when installing drivers for a new connection' => {
        name: 'Software\Policies\Microsoft\Windows NT\Printers\PointAndPrint\NoWarningNoElevationOnInstall',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Printers\PointAndPrint',
        value_name: 'NoWarningNoElevationOnInstall',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Point and Print Restrictions when updating drivers for an existing connection' => {
        name: 'Software\Policies\Microsoft\Windows NT\Printers\PointAndPrint\UpdatePromptSettings',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Printers\PointAndPrint',
        value_name: 'UpdatePromptSettings',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Prevent device metadata retrieval from the Internet' => {
        name: 'SOFTWARE\Policies\Microsoft\Windows\Device Metadata\PreventDeviceMetadataFromNetwork',
        configuration: 'Computer',
        registry_key: 'SOFTWARE\Policies\Microsoft\Windows\Device Metadata',
        value_name: 'PreventDeviceMetadataFromNetwork',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off cloud consumer account state content' => {
        name: 'Software\Policies\Microsoft\Windows\CloudContent\DisableConsumerAccountStateContent',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\CloudContent',
        value_name: 'DisableConsumerAccountStateContent',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Disable OneSettings Downloads' => {
        name: 'Software\Policies\Microsoft\Windows\DataCollection\DisableOneSettingsDownloads',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\DataCollection',
        value_name: 'DisableOneSettingsDownloads',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Enable OneSettings Auditing' => {
        name: 'Software\Policies\Microsoft\Windows\DataCollection\EnableOneSettingsAuditing',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\DataCollection',
        value_name: 'EnableOneSettingsAuditing',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Limit Diagnostic Log Collection' => {
        name: 'Software\Policies\Microsoft\Windows\DataCollection\LimitDiagnosticLogCollection',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\DataCollection',
        value_name: 'LimitDiagnosticLogCollection',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Limit Dump Collection' => {
        name: 'Software\Policies\Microsoft\Windows\DataCollection\LimitDumpCollection',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\DataCollection',
        value_name: 'LimitDumpCollection',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off Push To Install service' => {
        name: 'Software\Policies\Microsoft\PushToInstall\DisablePushToInstall',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\PushToInstall',
        value_name: 'DisablePushToInstall',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow Cloud Search' => {
        name: 'SOFTWARE\Policies\Microsoft\Windows\Windows Search\AllowCloudSearch',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Windows Search',
        value_name: 'AllowCloudSearch',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Manage preview builds (setting)' => {
        name: 'Software\Policies\Microsoft\Windows\WindowsUpdate\ManagePreviewBuilds',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\WindowsUpdate',
        value_name: 'ManagePreviewBuilds',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow UI Automation redirection' => {
        name: 'Software\Policies\Microsoft\Windows NT\Terminal Services\EnableUiaRedirection',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Terminal Services',
        value_name: 'EnableUiaRedirection',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Do not allow location redirection' => {
        name: 'Software\Policies\Microsoft\Windows NT\Terminal Services\fDisableLocationRedir',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Terminal Services',
        value_name: 'fDisableLocationRedir',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Manage preview builds (policy)' => {
        name: 'Software\Policies\Microsoft\Windows\WindowsUpdate\ManagePreviewBuildsPolicyValue',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\WindowsUpdate',
        value_name: 'ManagePreviewBuildsPolicyValue',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Configure RPC packet level privacy setting for incoming connections' => {
        name: 'SYSTEM\CurrentControlSet\Control\Print\RpcAuthnLevelPrivacyEnabled',
        configuration: 'Computer',
        registry_key: 'SYSTEM\CurrentControlSet\Control\Print',
        value_name: 'RpcAuthnLevelPrivacyEnabled',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Configure NetBIOS settings' => {
        name: 'Software\Policies\Microsoft\Windows NT\DNSClient\EnableNetbios',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\DNSClient',
        value_name: 'EnableNetbios',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '2',
        disabled_value: '0',
      },
      'Configure Redirection Guard' => {
        name: 'Software\Policies\Microsoft\Windows NT\Printers\RedirectionGuardPolicy',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Printers',
        value_name: 'RedirectionGuardPolicy',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Configure RPC connection settings: Protocol to use for outgoing RPC connections' => {
        name: 'Software\Policies\Microsoft\Windows NT\Printers\RPC\RpcUseNamedPipeProtocol',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Printers\RPC',
        value_name: 'RpcUseNamedPipeProtocol',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Configure RPC connection settings: Use authentication for outgoing RPC connections' => {
        name: 'Software\Policies\Microsoft\Windows NT\Printers\RPC\RpcAuthentication',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Printers\RPC',
        value_name: 'RpcAuthentication',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Configure RPC listener settings: Protocols to allow for incoming RPC connections' => {
        name: 'Software\Policies\Microsoft\Windows NT\Printers\RPC\RpcProtocols',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Printers\RPC',
        value_name: 'RpcProtocols',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '5',
        disabled_value: '0',
      },
      'Configure RPC listener settings: Authentication protocol to use for incoming RPC connections' => {
        name: 'Software\Policies\Microsoft\Windows NT\Printers\RPC\ForceKerberosForRpc',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Printers\RPC',
        value_name: 'ForceKerberosForRpc',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Configure RPC over TCP port' => {
        name: 'Software\Policies\Microsoft\Windows NT\Printers\RPC\RpcTcpPort',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Printers\RPC',
        value_name: 'RpcTcpPort',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '0',
        disabled_value: '1',
      },
      'Manage processing of Queue-specific files' => {
        name: 'Software\Policies\Microsoft\Windows NT\Printers\CopyFilesPolicy',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Printers',
        value_name: 'CopyFilesPolicy',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow Custom SSPs and APs to be loaded into LSASS' => {
        name: 'Software\Policies\Microsoft\Windows\System\AllowCustomSSPsAPs',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\System',
        value_name: 'AllowCustomSSPsAPs',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off cloud optimized content' => {
        name: 'Software\Policies\Microsoft\Windows\CloudContent\DisableCloudOptimizedContent',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\CloudContent',
        value_name: 'DisableCloudOptimizedContent',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Enable App Installer' => {
        name: 'Software\Policies\Microsoft\Windows\AppInstaller\EnableAppInstaller',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\AppInstaller',
        value_name: 'EnableAppInstaller',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Enable App Installer Experimental Features' => {
        name: 'Software\Policies\Microsoft\Windows\AppInstaller\EnableExperimentalFeatures',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\AppInstaller',
        value_name: 'EnableExperimentalFeatures',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Enable App Installer Hash Override' => {
        name: 'Software\Policies\Microsoft\Windows\AppInstaller\EnableHashOverride',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\AppInstaller',
        value_name: 'EnableHashOverride',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Enable App Installer ms-appinstaller protocol' => {
        name: 'Software\Policies\Microsoft\Windows\AppInstaller\EnableMSAppInstallerProtocol',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\AppInstaller',
        value_name: 'EnableMSAppInstallerProtocol',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Do not allow WebAuthn redirection' => {
        name: 'SOFTWARE\Policies\Microsoft\Windows NT\Terminal Services\fDisableWebAuthn',
        configuration: 'Computer',
        registry_key: 'SOFTWARE\Policies\Microsoft\Windows NT\Terminal Services',
        value_name: 'fDisableWebAuthn',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Allow search highlights' => {
        name: 'Software\Policies\Microsoft\Windows\Windows Search\EnableDynamicContentInWSB',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Windows Search',
        value_name: 'EnableDynamicContentInWSB',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Enable MPR notifications for the system' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\System\EnableMPR',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\System',
        value_name: 'EnableMPR',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Configure multicast DNS (mDNS) protocol' => {
        name: 'Software\Policies\Microsoft\Windows NT\DNSClient\EnableMDNS',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\DNSClient',
        value_name: 'EnableMDNS',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off default IPv6 DNS Servers' => {
        name: 'Software\Policies\Microsoft\Windows NT\DNSClient\DisableIPv6DefaultDnsServers',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\DNSClient',
        value_name: 'DisableIPv6DefaultDnsServers',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Audit client does not support encryption' => {
        name: 'Software\Policies\Microsoft\Windows\LanmanServer\AuditClientDoesNotSupportEncryption',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\LanmanServer',
        value_name: 'AuditClientDoesNotSupportEncryption',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Audit client does not support signing' => {
        name: 'Software\Policies\Microsoft\Windows\LanmanServer\AuditClientDoesNotSupportSigning',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\LanmanServer',
        value_name: 'AuditClientDoesNotSupportSigning',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'LanmanServer: Audit insecure guest logon' => {
        name: 'Software\Policies\Microsoft\Windows\LanmanServer\AuditInsecureGuestLogon',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\LanmanServer',
        value_name: 'AuditInsecureGuestLogon',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Enable authentication rate limiter' => {
        name: 'Software\Policies\Microsoft\Windows\LanmanServer\EnableAuthRateLimiter',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\LanmanServer',
        value_name: 'EnableAuthRateLimiter',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'LanmanServer: Enable remote mailslots' => {
        name: 'Software\Policies\Microsoft\Windows\Bowser\EnableMailslots',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Bowser',
        value_name: 'EnableMailslots',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'LanmanServer: Mandate the minimum version of SMB' => {
        name: 'Software\Policies\Microsoft\Windows\LanmanServer\MinSmb2Dialect',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\LanmanServer',
        value_name: 'MinSmb2Dialect',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Set authentication rate limiter delay (milliseconds)' => {
        name: 'Software\Policies\Microsoft\Windows\LanmanServer\InvalidAuthenticationDelayTimeInMs',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\LanmanServer',
        value_name: 'InvalidAuthenticationDelayTimeInMs',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'LanmanWorkstation: Audit insecure guest logon' => {
        name: 'Software\Policies\Microsoft\Windows\LanmanWorkstation\AuditInsecureGuestLogon',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\LanmanWorkstation',
        value_name: 'AuditInsecureGuestLogon',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Audit server does not support encryption' => {
        name: 'Software\Policies\Microsoft\Windows\LanmanWorkstation\AuditServerDoesNotSupportEncryption',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\LanmanWorkstation',
        value_name: 'AuditServerDoesNotSupportEncryption',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Audit server does not support signing' => {
        name: 'Software\Policies\Microsoft\Windows\LanmanWorkstation\AuditServerDoesNotSupportSigning',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\LanmanWorkstation',
        value_name: 'AuditServerDoesNotSupportSigning',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'LanmanWorkstation: Enable remote mailslots' => {
        name: 'Software\Policies\Microsoft\Windows\NetworkProvider\EnableMailslots',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\NetworkProvider',
        value_name: 'EnableMailslots',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'LanmanWorkstation: Mandate the minimum version of SMB' => {
        name: 'Software\Policies\Microsoft\Windows\LanmanWorkstation\MinSmb2Dialect',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\LanmanWorkstation',
        value_name: 'MinSmb2Dialect',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Require Encryption' => {
        name: 'Software\Policies\Microsoft\Windows\LanmanWorkstation\RequireEncryption',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\LanmanWorkstation',
        value_name: 'RequireEncryption',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Configure Windows protected print' => {
        name: 'Software\Policies\Microsoft\Windows NT\Printers\WPP\WindowsProtectedPrintGroupPolicyState',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Printers\WPP',
        value_name: 'WindowsProtectedPrintGroupPolicyState',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Block NetBIOS-based discovery for domain controller location' => {
        name: 'Software\Policies\Microsoft\Netlogon\Parameters\BlockNetbiosDiscovery',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Netlogon\Parameters',
        value_name: 'BlockNetbiosDiscovery',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Configure SAM change password RPC methods policy' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\System\SAM\SAMrchangeUserPasswordApiPolicy',
        configuration: 'Computer',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\System\SAM',
        value_name: 'SAMrchangeUserPasswordApiPolicy',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Not allow per-user unsigned packages to install by default (requires explicitly allow per install)' => {
        name: 'Software\Policies\Microsoft\Windows\Appx\DisablePerUserunsignedPackagesByDefault',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\Appx',
        value_name: 'DisablePerUserunsignedPackagesByDefault',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Enable App Installer Local Archive Malware Scan Override' => {
        name: 'Software\Policies\Microsoft\Windows\AppInstaller\EnableLocalArchiveMalwareScanOverride',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\AppInstaller',
        value_name: 'EnableLocalArchiveMalwareScanOverride',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Enable App Installer Microsoft Store Source Certificate Validation Bypass' => {
        name: 'Software\Policies\Microsoft\Windows\AppInstaller\EnableBypassCertificatePinningForMicrosoftStore',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\AppInstaller',
        value_name: 'EnableBypassCertificatePinningForMicrosoftStore',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Enable Windows Package Manager command line interfaces' => {
        name: 'Software\Policies\Microsoft\Windows\AppInstaller\EnableWindowsPackageManagerCommandLineInterfaces',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows\AppInstaller',
        value_name: 'EnableWindowsPackageManagerCommandLineInterfaces',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Restrict clipboard transfer from server to client' => {
        name: 'Software\Policies\Microsoft\Windows NT\Terminal Services\SCClipLevel',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Windows NT\Terminal Services',
        value_name: 'SCClipLevel',
        reg_type: 'DWORD',
        data_type: 'string',
      },
      'Turn on Basic feed authentication over HTTP' => {
        name: 'Software\Policies\Microsoft\Internet Explorer\Feeds\AllowBasicAuthInClear',
        configuration: 'Computer',
        registry_key: 'Software\Policies\Microsoft\Internet Explorer\Feeds',
        value_name: 'AllowBasicAuthInClear',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },

      # User
      'Enable screen saver' => {
        name: 'Software\Policies\Microsoft\Windows\Control Panel\Desktop\ScreenSaveActive',
        configuration: 'User',
        registry_key: 'Software\Policies\Microsoft\Windows\Control Panel\Desktop',
        value_name: 'ScreenSaveActive',
        reg_type: 'SZ',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Force specific screen saver' => {
        name: 'Software\Policies\Microsoft\Windows\Control Panel\Desktop\SCRNSAVE.EXE',
        configuration: 'User',
        registry_key: 'Software\Policies\Microsoft\Windows\Control Panel\Desktop',
        value_name: 'SCRNSAVE.EXE',
        reg_type: 'SZ',
        data_type: 'string',
      },
      'Password protect the screen saver' => {
        name: 'Software\Policies\Microsoft\Windows\Control Panel\Desktop\ScreenSaverIsSecure',
        configuration: 'User',
        registry_key: 'Software\Policies\Microsoft\Windows\Control Panel\Desktop',
        value_name: 'ScreenSaverIsSecure',
        reg_type: 'SZ',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Screen saver timeout' => {
        name: 'Software\Policies\Microsoft\Windows\Control Panel\Desktop\ScreenSaveTimeOut',
        configuration: 'User',
        registry_key: 'Software\Policies\Microsoft\Windows\Control Panel\Desktop',
        value_name: 'ScreenSaveTimeOut',
        reg_type: 'SZ',
        data_type: 'string',
      },
      'Turn off toast notifications on the lock screen' => {
        name: 'SOFTWARE\Policies\Microsoft\Windows\CurrentVersion\PushNotifications\NoToastApplicationNotificationOnLockScreen',
        configuration: 'User',
        registry_key: 'SOFTWARE\Policies\Microsoft\Windows\CurrentVersion\PushNotifications',
        value_name: 'NoToastApplicationNotificationOnLockScreen',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off Help Experience Improvement Program' => {
        name: 'Software\Policies\Microsoft\Assistance\Client\1.0\NoImplicitFeedback',
        configuration: 'User',
        registry_key: 'Software\Policies\Microsoft\Assistance\Client\1.0',
        value_name: 'NoImplicitFeedback',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Do not preserve zone information in file attachments' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\Attachments\SaveZoneInformation',
        configuration: 'User',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\Attachments',
        value_name: 'SaveZoneInformation',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '2',
      },
      'Notify antivirus programs when opening attachments' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\Attachments\ScanWithAntiVirus',
        configuration: 'User',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\Attachments',
        value_name: 'ScanWithAntiVirus',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '3',
        disabled_value: '1',
      },
      'Configure Windows spotlight on lock screen' => {
        name: 'Software\Policies\Microsoft\Windows\CloudContent\ConfigureWindowsSpotlight',
        configuration: 'User',
        registry_key: 'Software\Policies\Microsoft\Windows\CloudContent',
        value_name: 'ConfigureWindowsSpotlight',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '2',
      },
      'Do not suggest third-party content in Windows spotlight' => {
        name: 'Software\Policies\Microsoft\Windows\CloudContent\DisableThirdPartySuggestions',
        configuration: 'User',
        registry_key: 'Software\Policies\Microsoft\Windows\CloudContent',
        value_name: 'DisableThirdPartySuggestions',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Do not use diagnostic data for tailored experiences' => {
        name: 'Software\Policies\Microsoft\Windows\CloudContent\DisableTailoredExperiencesWithDiagnosticData',
        configuration: 'User',
        registry_key: 'Software\Policies\Microsoft\Windows\CloudContent',
        value_name: 'DisableTailoredExperiencesWithDiagnosticData',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off all Windows spotlight features' => {
        name: 'Software\Policies\Microsoft\Windows\CloudContent\DisableWindowsSpotlightFeatures',
        configuration: 'User',
        registry_key: 'Software\Policies\Microsoft\Windows\CloudContent',
        value_name: 'DisableWindowsSpotlightFeatures',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Turn off Spotlight collection on Desktop' => {
        name: 'Software\Policies\Microsoft\Windows\CloudContent\DisableSpotlightCollectionOnDesktop',
        configuration: 'User',
        registry_key: 'Software\Policies\Microsoft\Windows\CloudContent',
        value_name: 'DisableSpotlightCollectionOnDesktop',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Prevent users from sharing files within their profile' => {
        name: 'Software\Microsoft\Windows\CurrentVersion\Policies\Explorer\NoInplaceSharing',
        configuration: 'User',
        registry_key: 'Software\Microsoft\Windows\CurrentVersion\Policies\Explorer',
        value_name: 'NoInplaceSharing',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Always install with elevated privileges user' => {
        name: 'Software\Policies\Microsoft\Windows\Installer\AlwaysInstallElevated',
        configuration: 'User',
        registry_key: 'Software\Policies\Microsoft\Windows\Installer',
        value_name: 'AlwaysInstallElevated',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
      'Prevent Codec Download' => {
        name: 'Software\Policies\Microsoft\WindowsMediaPlayer\PreventCodecDownload',
        configuration: 'User',
        registry_key: 'Software\Policies\Microsoft\WindowsMediaPlayer',
        value_name: 'PreventCodecDownload',
        reg_type: 'DWORD',
        data_type: 'boolean',
        enabled_value: '1',
        disabled_value: '0',
      },
    }
  end
end
